@@ -22,20 +22,6 @@ class StackageBackend(BaseBackend):
         "https://www.stackage.org/package/cabal-install",
     ]
 
-    @classmethod
-    def get_version(cls, project):
-        """Method called to retrieve the latest version of the projects
-        provided, project that relies on the backend of this plugin.
-        :arg Project project: a :class:`anitya.db.models.Project` object whose backend
-            corresponds to the current plugin.
-        :return: the latest version found upstream
-        :return type: str
-        :raise AnityaPluginException: a
-            :class:`anitya.lib.exceptions.AnityaPluginException` exception
-            when the version cannot be retrieved correctly
-        """
-        return cls.get_ordered_versions(project)[-1]
-
     @classmethod
     def get_version_url(cls, project):
         """Method called to retrieve the url used to check for new version
